@@ -24,7 +24,7 @@ class Plugin(Plugin):
 
     needs_plugins = ['lino.modlib.bootstrap3']
 
-    def on_ui_init(self, ui):
+    def on_ui_init(self, kernel):
         from .renderer import Renderer
         self.renderer = Renderer(self)
 
@@ -47,4 +47,3 @@ class Plugin(Plugin):
     def get_index_view(self):
         from . import views
         return views.Index.as_view()
-
