@@ -13,7 +13,7 @@ from lino.modlib.users.mixins import Assignable
 from lino.modlib.summaries.mixins import Summarized
 from lino_xl.lib.tickets.models import *
 from lino_xl.lib.working.choicelists import ReportingTypes, ZERO_DURATION
-from lino.modlib.elastic.mixins import ElasticSearchable
+from lino.modlib.search.mixins import ElasticSearchable
 
 
 def get_summary_fields():
@@ -57,7 +57,119 @@ class Ticket(Ticket, Assignable, Summarized, ElasticSearchable):
         # app_label = 'tickets'
         abstract = dd.is_abstract_model(__name__, 'Ticket')
 
-    ES_indexes = {('ticket',)}
+    ES_indexes = [(
+        'ticket',
+        {
+            "mappings": {
+                "properties": {
+                    "closed": {
+                        "type": "boolean"
+                    },
+                    "description": {
+                        "type": "text",
+                        "fields": {
+                            "keyword": {
+                                "type": "keyword",
+                                "ignore_above": 256
+                            }
+                        },
+                        "analyzer": "autocomplete",
+                        "search_analyzer": "autocomplete_search"
+                    },
+                    "end_user": {
+                        "type": "long"
+                    },
+                    "feedback": {
+                        "type": "boolean"
+                    },
+                    "model": {
+                        "type": "text",
+                        "fields": {
+                            "keyword": {
+                                "type": "keyword",
+                                "ignore_above": 256
+                            }
+                        },
+                        "analyzer": "autocomplete",
+                        "search_analyzer": "autocomplete_search"
+                    },
+                    "priority": {
+                        "type": "long"
+                    },
+                    "private": {
+                        "type": "boolean"
+                    },
+                    "site": {
+                        "type": "long"
+                    },
+                    "standby": {
+                        "type": "boolean"
+                    },
+                    "state": {
+                        "properties": {
+                            "text": {
+                                "type": "text",
+                                "fields": {
+                                    "keyword": {
+                                        "type": "keyword",
+                                        "ignore_above": 256
+                                    }
+                                }
+                            },
+                            "value": {
+                                "type": "text",
+                                "fields": {
+                                    "keyword": {
+                                        "type": "keyword",
+                                        "ignore_above": 256
+                                    }
+                                }
+                            }
+                        }
+                    },
+                    "summary": {
+                        "type": "text",
+                        "fields": {
+                            "keyword": {
+                                "type": "keyword",
+                                "ignore_above": 256
+                            }
+                        },
+                        "analyzer": "autocomplete",
+                        "search_analyzer": "autocomplete_search"
+                    },
+                    "ticket_type": {
+                        "type": "long"
+                    },
+                    "upgrade_notes": {
+                        "type": "text",
+                        "fields": {
+                            "keyword": {
+                                "type": "keyword",
+                                "ignore_above": 256
+                            }
+                        },
+                        "analyzer": "autocomplete",
+                        "search_analyzer": "autocomplete_search"
+                    },
+                    "user": {
+                        "type": "long"
+                    },
+                    "waiting_for": {
+                        "type": "text",
+                        "fields": {
+                            "keyword": {
+                                "type": "keyword",
+                                "ignore_above": 256
+                            }
+                        },
+                        "analyzer": "autocomplete",
+                        "search_analyzer": "autocomplete_search"
+                    }
+                }
+            }
+        }
+    )]
 
     def assigned_to_changed(self, ar):
         """Add a star and send notification of Assignment"""
